"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var ivy_angular_data_1 = require("ivy.angular.data");
var MaterialPaginatedListComponent = /** @class */ (function () {
    function MaterialPaginatedListComponent() {
        this.pageCounts = [5, 10, 25, 50, 100];
        this.pageCountCache = 1;
        this.requestInit = false;
        /*
         * Any time the pagination request changes, we'll simply return the new value to a higher context.
         * The higher context will then be capable of taking the new request and firing it off to the server.
         * This ensures this component is responsible for setting up the PaginatedRequest and rending can
         * still be appropriately handled in a higher context.
         *
         * We will emit data on....
         * 1) Change page
         * 2) Change page size
         * 3) Hit search button
         */
        this.onPaginationChange = new core_1.EventEmitter();
        this.request = new ivy_angular_data_1.PaginatedRequest();
    }
    MaterialPaginatedListComponent.prototype.ngOnInit = function () {
        this.refreshPagination();
    };
    MaterialPaginatedListComponent.prototype.refreshPagination = function () {
        // Let's reset the spinner motion
        this.response = null;
        this.onPaginationChange.emit(this.request);
    };
    MaterialPaginatedListComponent.prototype.refreshTotalPages = function () {
        var newTotalPages = this.getTotalPages();
        if (newTotalPages < this.request.pageNumber) {
            this.request.pageNumber = newTotalPages;
        }
        this.refreshPagination();
    };
    MaterialPaginatedListComponent.prototype.getTotalPages = function () {
        if (this.response != null) {
            var totalPages = this.response.totalCount / this.request.pageCount;
            var roundedPages = Math.floor(totalPages);
            /*
             * do we need to round down here and add one ???
             * what if we are at the exact final page length ???
             */
            if (totalPages == 0) {
                return this.setCachedPagesAndReturn(1);
            }
            else if (totalPages == roundedPages) {
                return this.setCachedPagesAndReturn(roundedPages);
            }
            else {
                return this.setCachedPagesAndReturn(roundedPages + 1);
            }
        }
        return this.pageCountCache;
    };
    MaterialPaginatedListComponent.prototype.showNoData = function () {
        if (this.response == null)
            return false;
        if (this.response.totalCount == 0)
            return true;
        return false;
    };
    MaterialPaginatedListComponent.prototype.nextPage = function () {
        if (this.canMoveNext()) {
            this.request.pageNumber++;
            this.refreshPagination();
        }
    };
    MaterialPaginatedListComponent.prototype.previousPage = function () {
        if (this.canMovePrevious()) {
            this.request.pageNumber--;
            this.refreshPagination();
        }
    };
    MaterialPaginatedListComponent.prototype.canMoveNext = function () {
        var totalPages = this.getTotalPages();
        return this.request.pageNumber < totalPages;
    };
    MaterialPaginatedListComponent.prototype.canMovePrevious = function () {
        return this.request.pageNumber > 1;
    };
    MaterialPaginatedListComponent.prototype.getGtXsToolbarAlignment = function () {
        if (this.hideSearch) {
            return 'center';
        }
        else {
            return 'start';
        }
    };
    MaterialPaginatedListComponent.prototype.setCachedPagesAndReturn = function (cacheNum) {
        this.pageCountCache = cacheNum;
        return cacheNum;
    };
    __decorate([
        core_1.Output(),
        __metadata("design:type", core_1.EventEmitter)
    ], MaterialPaginatedListComponent.prototype, "onPaginationChange", void 0);
    __decorate([
        core_1.Input(),
        __metadata("design:type", ivy_angular_data_1.BasePaginatedResponse)
    ], MaterialPaginatedListComponent.prototype, "response", void 0);
    __decorate([
        core_1.Input(),
        __metadata("design:type", Boolean)
    ], MaterialPaginatedListComponent.prototype, "hideSearch", void 0);
    __decorate([
        core_1.Input(),
        __metadata("design:type", String)
    ], MaterialPaginatedListComponent.prototype, "pageCountText", void 0);
    __decorate([
        core_1.Input(),
        __metadata("design:type", String)
    ], MaterialPaginatedListComponent.prototype, "searchText", void 0);
    __decorate([
        core_1.Input(),
        __metadata("design:type", String)
    ], MaterialPaginatedListComponent.prototype, "noDataText", void 0);
    MaterialPaginatedListComponent = __decorate([
        core_1.Component({
            selector: 'ivy-material-paginated-list',
            templateUrl: './paginated-list.component.html',
            styles: [
                "./paginated-list.component.css"
            ]
        }),
        __metadata("design:paramtypes", [])
    ], MaterialPaginatedListComponent);
    return MaterialPaginatedListComponent;
}());
exports.MaterialPaginatedListComponent = MaterialPaginatedListComponent;
//# sourceMappingURL=paginated-list.component.js.map